@@ -23,7 +23,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-`Xplot` <- function(x, jitter = FALSE, at = NULL, ...) {
+`Xplot` <- function(x, jitter = FALSE, at = pretty(x), ...) {
     other.args <- list(...)
     funargs <- unlist(lapply(match.call(), deparse)[-1])
     xname <- getName(funargs[1])
